changeset 67:1bf41957418f

Update notes in build.sh script
author Andre Heinecke <aheinecke@intevation.de>
date Tue, 18 Mar 2014 18:26:14 +0000
parents 4f79cf993737
children 8ffbb48528ae
files build.sh
diffstat 1 files changed, 6 insertions(+), 4 deletions(-) [+]
line wrap: on
line diff
--- a/build.sh	Tue Mar 18 16:37:40 2014 +0100
+++ b/build.sh	Tue Mar 18 18:26:14 2014 +0000
@@ -17,14 +17,16 @@
 cd ..
 mkdir -p build-windows
 cd build-windows
-cmake .. -DCMAKE_PREFIX_PATH=~/wheezy/src/mxe/usr/i686-w64-mingw32/qt5 \
-    -DCMAKE_TOOLCHAIN_FILE='~/wheezy/src/mxe/usr/i686-w64-mingw32/share/cmake/mxe-conf.cmake' \
+cmake .. \
+    -DCMAKE_PREFIX_PATH="~/ubuntu/src/mxe/usr/i686-w64-mingw32.static" \
+    -DCMAKE_TOOLCHAIN_FILE='~/ubuntu/src/mxe/usr/i686-w64-mingw32.static/share/cmake/mxe-conf.cmake' \
     -DCMAKE_VERBOSE_MAKEFILE=True
 nice make -j8
 cd ..
 
 # Note: qt5 plugins have .lib suffix
 # find ~/wheezy/src/mxe/usr/i686-w64-mingw32/qt5/lib/cmake -name \*.cmake | xargs sed -i 's/\.lib/\.a//g'
 # Also they need to have a lib prefixed...
 # Then there is a bogous call _qt5gui_find_extra_libs(OPENGL "glu32;opengl32;gdi32;user32" "" "")
 # where the second "" has to be replaced by your windows prefix. e.g. /home/andre/wheezy/src/mxe/usr/i686-w64-mingw32/lib
@@ -17,14 +17,16 @@
 
 # Note: qt5 plugins have .lib suffix
-# find ~/wheezy/src/mxe/usr/i686-w64-mingw32/qt5/lib/cmake -name \*.cmake | xargs sed -i 's/\.lib/\.a//g'
+# find ~/ubuntu/src/mxe/usr/i686-w64-mingw32.static/qt5/lib/cmake -name \*.cmake | xargs sed -i 's/\/([a-z]*)\.lib/\/lib\1\.a/g'
 # Also they need to have a lib prefixed...
 # Then there is a bogous call _qt5gui_find_extra_libs(OPENGL "glu32;opengl32;gdi32;user32" "" "")
@@ -17,14 +17,16 @@
 # Also they need to have a lib prefixed...
 # Then there is a bogous call _qt5gui_find_extra_libs(OPENGL "glu32;opengl32;gdi32;user32" "" "")
-# where the second "" has to be replaced by your windows prefix. e.g. /home/andre/wheezy/src/mxe/usr/i686-w64-mingw32/lib
+# where the first "" has to be replaced by your windows prefix. e.g.
+# /home/andre/ubuntu/src/mxe/usr/i686-w64-mingw32.static/lib

http://wald.intevation.org/projects/trustbridge/

http://wald.intevation.org/projects/trustbridge/